@@ -38,30 +38,23 @@ class RepeatingArea(Repeating):
     >>> assert "$7.00" == inventory.areas[5].price
     """
 
-    def __init__(self, **kwargs):
-        if kwargs.get('root') is None:
-            raise ValueError('RepeatingArea requires a Root Field.')
+    def __init__(self, root: Field, **kwargs):
+        self.root = root
+        self.repeater = Area
+        self.repeater_name = self.repeater.__name__
 
-        self.root = kwargs['root']
-
-        if kwargs.get('items') is not None:
-            raise ValueError('"items" is a reserved parameter.')
-
-        self.items = {}
+        self._items = {}
         for k, v in kwargs.items():
-            if not isinstance(v, Field) and not isinstance(v, Area):
+            if not isinstance(v, (Field, Area)):
                 raise ValueError(
                     'RepeatingArea arguments can only be a Field or Area.',
                 )
             if k != 'root':
-                self.items[k] = v
+                self._items[k] = v
                 # Field (in plural) can be accessed directly.
                 setattr(self, f'{k}s', v)
 
-        self.repeater = Area
-        self.repeater_name = self.repeater.__name__
-
-    def new_container(self):
+    def new_container(self) -> Areas:
         """Get a new instance of the container this class uses.
 
         Returns:
@@ -71,7 +64,7 @@ class RepeatingArea(Repeating):
         return Areas()
 
     @property
-    def areas(self):
+    def areas(self) -> Areas:
         """Find all instances of the root,
         then return a list of Areas: one for each root.
 
@@ -87,7 +80,7 @@ class RepeatingArea(Repeating):
         """
         return self.children()
 
-    def children(self):
+    def children(self) -> Areas:
         """Find all instances of the root,
         then return a list of Areas: one for each root.
 
@@ -104,17 +97,23 @@ class RepeatingArea(Repeating):
         all_roots = self._all_roots()
         container = self.new_container()
 
-        for item in all_roots:
-            copy_items = copy.deepcopy(self.items)
+        for root in all_roots:
+            copy_items = copy.deepcopy(self._items)
             for field_name in copy_items.keys():
                 child = copy_items[field_name]
+
+                # Every Field in the Area gets the root set here.
                 if isinstance(child, Field):
-                    child._element.parent_locator = item
+                    child._element.parent_locator = root
+                # Area inside an Area
                 elif isinstance(child, Area):
+                    # Has root
                     if child.root:
-                        child.root._element.parent_locator = item
+                        child.root._element.parent_locator = root
+                    # Has no root
                     else:
-                        child._element.parent_locator = item
+                        for _, v in child._items.items():
+                            v._element.parent_locator = root
 
             new_area = self.repeater(**copy_items)
             container.append(new_area)
